package agilprotests;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Properties;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.edit.provider.*;
import org.eclipse.emf.edit.provider.resource.ResourceItemProviderAdapterFactory;

import model.application.ApplicationPackage;
import model.core.CoreFactory;
import model.core.CorePackage;
import model.core.impl.PackageImpl;
import model.data.DataPackage;
import model.events.EventsPackage;
import model.functions.FunctionsPackage;
import model.organisations.OrganisationsPackage;
import model.organisations.impl.RoleImpl;
import model.primitiveTypes.PrimitiveTypesPackage;
import model.processes.ProcessesPackage;
import model.processes.impl.ActionImpl;
import model.processes.impl.ActivityImpl;
import model.processes.impl.ReferenceEdgeImpl;
import model.processes.impl.ReferenceImpl;
import model.view.Point;
import model.view.ViewPackage;
import model.view.impl.PointImpl;

import org.eclipse.emf.common.command.BasicCommandStack;
import org.eclipse.emf.common.notify.AdapterFactory;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.EPackage;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.emf.ecore.xmi.impl.XMIResourceFactoryImpl;
import org.eclipse.emf.edit.domain.AdapterFactoryEditingDomain;
import org.eclipse.emf.edit.domain.EditingDomain;
import org.eclipse.emf.teneo.PersistenceOptions;
import org.eclipse.emf.teneo.hibernate.HbDataStore;
import org.eclipse.emf.teneo.hibernate.HbHelper;
import org.eclipse.emf.teneo.hibernate.resource.HibernateResourceFactory;
import org.eclipse.gef.EditDomain;
import org.eclipse.gef.palette.PaletteRoot;
import org.eclipse.ui.part.MultiPageEditorPart;
import org.hibernate.cfg.Environment;

import de.uniAugsburg.agilPro.editors.GefEmfEditingDomain;
import de.uniAugsburg.agilPro.editors.palette.Palette;
import de.uniAugsburg.agilPro.model.commands.gefEmfAdapter.GefToEmfCommandStackAdapter;
import de.uniAugsburg.agilPro.parts.AgilProAdapterFactoryEditingDomain;

import junit.framework.TestCase;


public class AgilProTests extends MultiPageEditorPart {
	
	private HbDataStore hbds=null;
	private EditDomain editDomain;
	private EditingDomain editingDomain;
	private PaletteRoot paletteModel;
	
	protected void createPages() {
	}
	public void doSave(IProgressMonitor monitor) {
	}

	public void doSaveAs() {
	}

	public boolean isSaveAsAllowed() {
		return false;
	}
	
	/*********************************************************************************/
	
	private void initHibernateStore() {
		System.out.println("-> initializing hibernate datastore");
		// Initialize the HbDataStore
		hbds = HbHelper.INSTANCE.createRegisterDataStore("agilprodb");
		hbds.setEPackages(new EPackage[]{CorePackage.eINSTANCE,
				                         ApplicationPackage.eINSTANCE,
				                         DataPackage.eINSTANCE,
				                         EventsPackage.eINSTANCE,
				                         FunctionsPackage.eINSTANCE,
				                         OrganisationsPackage.eINSTANCE,
				                         PrimitiveTypesPackage.eINSTANCE,
				                         ProcessesPackage.eINSTANCE,
				                         ViewPackage.eINSTANCE});
		hbds.setPersistenceProperties(getPersistenceProperties());
		hbds.setHibernateProperties(getDatabaseProperties());		
		hbds.initialize();		
	}
	
	private Properties getPersistenceProperties() {
		
		// set inheritance mapping type to joined!
		Properties props = new Properties();			
		props.setProperty(PersistenceOptions.INHERITANCE_MAPPING, "JOINED");
		
		// return result
		return props;
	}

	private Properties getDatabaseProperties() {
		/*
		 * properties may change in other environment...
		 */	
		
		// generate properties
		Properties props = new Properties();			
		props.setProperty(Environment.DRIVER, "com.mysql.jdbc.Driver");
		props.setProperty(Environment.USER, "root");
		props.setProperty(Environment.URL, "jdbc:mysql://127.0.0.1:3306/teneotestbase");
		props.setProperty(Environment.PASS, "root");
		props.setProperty(Environment.DIALECT, org.hibernate.dialect.MySQLInnoDBDialect.class.getName());
		props.setProperty(Environment.CURRENT_SESSION_CONTEXT_CLASS,"thread");
		
		// return result
		return props;
	}
	
	private void registerPackages(ResourceSet resourceSet) {
		
		// register epackages
		resourceSet.getPackageRegistry().put(CorePackage.eNS_URI,
		        CorePackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(ProcessesPackage.eNS_URI,
		        ProcessesPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(ApplicationPackage.eNS_URI,
				ApplicationPackage.eINSTANCE);		
		resourceSet.getPackageRegistry().put(DataPackage.eNS_URI,
				DataPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(EventsPackage.eNS_URI,
				EventsPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(FunctionsPackage.eNS_URI,
				FunctionsPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(OrganisationsPackage.eNS_URI,
				OrganisationsPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(PrimitiveTypesPackage.eNS_URI,
				PrimitiveTypesPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(ProcessesPackage.eNS_URI,
				ProcessesPackage.eINSTANCE);
		resourceSet.getPackageRegistry().put(ViewPackage.eNS_URI,
				ViewPackage.eINSTANCE);	
	}

	/*
	 * Load model "test.agilpro" from filesystem and save it in db. 
	 */
	private void loadAndSaveModel() throws Exception {
		System.out.println("-> loading model from filesystem and saving it in database");
		// get and load the resource from filesystem
		final URI uri = URI.createURI("Standard.agilpro");
		Resource fileResource = editingDomain.getResourceSet().createResource(uri);
		fileResource.load (Collections.EMPTY_MAP);
		
		// get and save the resource in the database		
		URI databaseURI = URI.createURI("hibernate://?dsname=agilprodb&query1=from Package where name='Standard'");        
        Resource databaseResource = editingDomain.getResourceSet().getResource(databaseURI,true);
        databaseResource.load(Collections.EMPTY_MAP);
        databaseResource.getContents().clear();
        databaseResource.getContents().add(fileResource.getAllContents().next());
        databaseResource.save(Collections.EMPTY_MAP);
	}

	private EditingDomain createEmfEditingDomain(AgilProTests instance) {
		
	    // Create an adapter factory that yields item providers.
	    List factories = new ArrayList();
	    factories.add(new ResourceItemProviderAdapterFactory());	    
	    factories.add(new ReflectiveItemProviderAdapterFactory());
	    AdapterFactory adapterFactory = new ComposedAdapterFactory(factories);
	    return new AgilProAdapterFactoryEditingDomain(
	                                           adapterFactory,
	                                           new GefToEmfCommandStackAdapter(
	                                                                           editDomain
	                                                                        .getCommandStack()));	    
	}		
			
	private void initializeEditingDomain() {
		System.out.println("-> initializing editing domain");
		editingDomain =   ((GefEmfEditingDomain) editDomain).getEmfEditingDomain();
		editingDomain.getResourceSet().getResourceFactoryRegistry().getExtensionToFactoryMap()
		    .put("agilprodb", new HibernateResourceFactory());
		editingDomain.getResourceSet().getResourceFactoryRegistry().getExtensionToFactoryMap()
	    .put("agilpro", new XMIResourceFactoryImpl());		
		registerPackages(editingDomain.getResourceSet());
	}	
		
	private void createEditDomain(EditDomain newEditDomain,AgilProTests instance) {
		System.out.println("-> creating edit domain");
	  editDomain = newEditDomain;
	  if (editDomain instanceof GefEmfEditingDomain)
	  {
	    ((GefEmfEditingDomain) editDomain)
	        .setEmfEditingDomain(createEmfEditingDomain(instance));
	  }
	}
	
	public static void main(String[] args) throws IOException {
		try {
			AgilProTests instance = new AgilProTests();
			
			// init database
			instance.initHibernateStore();
			
			// set the editing domain (with palette!)
			instance.createEditDomain(new GefEmfEditingDomain(instance),instance);
			
			// initialize the editing domain
			instance.initializeEditingDomain();
				
			// cannot save the Standard.agilpro resource!! Throws exception!
			instance.loadAndSaveModel(); 
			
			// done work
			System.out.println("-> done");
		}
		catch(Exception ex) {
			ex.printStackTrace();
		}
	}
}
