/**
 * File:    CreateReferenceFactory.java
 * Created: 27.03.2006
 *
 *
 * Copyright (c) 2006  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */


package de.uniAugsburg.agilPro.editors.factories;


import org.eclipse.gef.requests.CreationFactory;

import model.core.ReferenceableElement;
import model.processes.ProcessesFactory;
import model.processes.Reference;




/**
 * A factory that creates a {@link Reference} to a {@link ReferenceableElement}.
 * 
 * @version $Id: CreateReferenceFactory.java 169 2006-03-28 03:32:28Z bauermar $
 * @author Markus Bauer <markusbauer@users.sourceforge.net>
 */
public class CreateReferenceFactory
    implements CreationFactory
{
  /**
   * The {@link ReferenceableElement} for that a {@link Reference} will is
   * created.
   */
  private ReferenceableElement element;




  /**
   * @param element The {@link ReferenceableElement} for that a
   *          {@link Reference} will is created.
   */
  public CreateReferenceFactory(ReferenceableElement element)
  {
    assert element != null;
    this.element = element;
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.requests.CreationFactory#getNewObject()
   */
  public Object getNewObject()
  {
    Reference reference = ProcessesFactory.eINSTANCE.createReference();
    reference.setReference(element);
    
    return reference;
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.requests.CreationFactory#getObjectType()
   */
  public Object getObjectType()
  {
    return Reference.class;
  }

}
