/**
 * File:    EcoreCopyFactory.java
 * Created: 24.03.2006
 *
 *
 * Copyright (c) 2006  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */


package de.uniAugsburg.agilPro.editors.factories;


import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.util.EcoreUtil;

import model.core.ReferenceableElement;




/**
 * This factory creates new Object by copying existing Ecore {@link EObject}s.
 * 
 * <p>
 * This factory is also a {@link TransferFactory} and allows direct access to
 * the transfered object.
 * </p>
 * 
 * @version $Id: EcoreCopyFactory.java 287 2006-04-28 03:59:06Z bauermar $
 * @author Markus Bauer <markusbauer@users.sourceforge.net>
 */
public class EcoreCopyFactory
    extends TransferFactory
{
  /**
   * @param sourceObject The object to copy.
   */
  public EcoreCopyFactory(EObject sourceObject)
  {
    super(sourceObject);
  }



  /*
   * @param sourceObjects The objects to copy.
   */
  public EcoreCopyFactory(Collection sourceObjects)
  {
    super(sourceObjects);
  }



  /**
   * @return A copy of the transfered object.
   * 
   * @see org.eclipse.gef.requests.CreationFactory#getNewObject()
   */
  @Override
  public Object getNewObject()
  {
	// bugfix: dragndrop outline.refelement -> scope.reference (<-> scopelayouteditpolicy)
  	// object == refelement -> return refelement
	// object != refelement -> return copy of element
	  
    if (getTransferObject() instanceof EObject)
    {
	    if (getTransferObject() instanceof ReferenceableElement)
	    	return getTransferObject();
	    else
		    return EcoreUtil.copy((EObject) getTransferObject());
    }
    else if (getTransferObject() instanceof Collection)
    {
    	Collection returnlist = new ArrayList();

    	for (Iterator i = ((Collection)getTransferObject()).iterator(); i.hasNext();)
    	{
    		Object object = i.next();
    	    if (object instanceof ReferenceableElement)
    	    	returnlist.add(object);
    	    else
    	    	returnlist.add(EcoreUtil.copy((EObject) object));
    	}
    	return returnlist;
    }

    return null;
  }
}
