/**
 * File:    EcoreFactory.java
 * Created: 08.12.2005
 *
 *
 * Copyright (c) 2005  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, 
 * MA  02111-1307, USA.
 */


package de.uniAugsburg.agilPro.editors.factories;


import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.util.EcoreUtil;
import org.eclipse.gef.requests.CreationFactory;





/**
 * This factory creates new object from Ecore {@link EClass}es.
 * 
 * @version $Id: EcoreFactory.java 534 2006-09-20 14:04:58Z fischewo $
 * @author Markus Bauer <markusbauer@users.sourceforge.net>
 */
public class EcoreFactory
    implements CreationFactory
{

  /**
   * The class to create.
   */
  private EClass eClass;




  /**
   * @param eClass The class to create.
   */
  public EcoreFactory(EClass eClass)
  {
    this.eClass = eClass;
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.requests.CreationFactory#getNewObject()
   */
  public Object getNewObject()
  {
    if (eClass == null)
    {
      return null;
    }
    
    Object newObject = null;

    try
    {
    	newObject = EcoreUtil.create(eClass);
    }
    catch (Throwable error)
    {
    }

    return newObject;
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.requests.CreationFactory#getObjectType()
   */
  public Object getObjectType()
  {
    if (eClass == null)
    {
      return null;
    }
    
    return eClass.getInstanceClass();
  }
}
