/**
 * File:    TransferFactory.java
 * Created: 14.03.2006
 *
 *
 * Copyright (c) 2006  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */


package de.uniAugsburg.agilPro.editors.factories;


import org.eclipse.gef.requests.CreationFactory;




/**
 * A factory that does not create a new object, but simply transfers a given
 * object.
 * 
 * <p>
 * This class can be used for drag & drop.
 * </p>
 * 
 * @version $Id: TransferFactory.java 288 2006-04-28 03:59:44Z bauermar $
 * @author Markus Bauer (markusbauer@users.sourceforge.net)
 */
public class TransferFactory
    implements CreationFactory
{
  /**
   * The object that is transfered.
   */
  private Object object;




  /**
   * @param object The object that is transfered.
   */
  public TransferFactory(Object object)
  {
    assert object != null;
    this.object = object;
  }



  /**
   * @return The object that is transfered. Not <code>null</code>.
   */
  public Object getTransferObject()
  {
    return object;
  }



  /**
   * @return The object itself.
   * 
   * @see org.eclipse.gef.requests.CreationFactory#getNewObject()
   */
  public Object getNewObject()
  {
    return getTransferObject();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.requests.CreationFactory#getObjectType()
   */
  public Object getObjectType()
  {
    return object.getClass();
  }
}
