/**
 * File:    EmfToGefCommandAdapter.java
 * Created: 03.03.2006
 *
 *
 * Copyright (c) 2006  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */


package de.uniAugsburg.agilPro.model.commands.gefEmfAdapter;


import org.eclipse.emf.common.command.Command;




/**
 * Adapts an EMF command to be a GEF command.
 * 
 * @version $Id: EmfToGefCommandAdapter.java 93 2006-03-16 02:33:59Z bauermar $
 * @author Markus Bauer <markusbauer@users.sourceforge.net>
 */
public class EmfToGefCommandAdapter
    extends org.eclipse.gef.commands.Command
{
  /**
   * The EMF command.
   */
  private Command emfCommand;




  /**
   * Creates a new adapter without an EMF command. The EMF command must be set
   * before calling any other method.
   */
  public EmfToGefCommandAdapter()
  {
  }



  /**
   * @param emfCommand The EMF command.
   */
  public EmfToGefCommandAdapter(Command emfCommand)
  {
    this(null, emfCommand);
  }



  /**
   * @param label The Command's label.
   * @param emfCommand The EMF command.
   */
  public EmfToGefCommandAdapter(String label, Command emfCommand)
  {
    super(label);
    this.emfCommand = emfCommand;
  }



  /**
   * @return Returns the emfCommand.
   */
  public Command getEmfCommand()
  {
    return emfCommand;
  }



  /**
   * @param emfCommand The emfCommand to set.
   */
  public void setEmfCommand(Command emfCommand)
  {
    this.emfCommand = emfCommand;
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#getDebugLabel()
   */
  @Override
  public String getDebugLabel()
  {
    if (super.getDebugLabel() != null)
    {
      return super.getDebugLabel();
    }

    return emfCommand.getDescription();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#getLabel()
   */
  @Override
  public String getLabel()
  {
    if (super.getLabel() != null)
    {
      return super.getLabel();
    }

    return emfCommand.getLabel();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#canExecute()
   */
  @Override
  public boolean canExecute()
  {
    return emfCommand.canExecute();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#canUndo()
   */
  @Override
  public boolean canUndo()
  {
    return emfCommand.canUndo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#execute()
   */
  @Override
  public void execute()
  {
    emfCommand.execute();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#redo()
   */
  @Override
  public void redo()
  {
    emfCommand.redo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#undo()
   */
  @Override
  public void undo()
  {
    emfCommand.undo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.gef.commands.Command#dispose()
   */
  @Override
  public void dispose()
  {
    emfCommand.dispose();
  }
}
