/**
 * File:    GefToEmfCommandStackAdapter.java
 * Created: 07.03.2006
 *
 *
 * Copyright (c) 2006  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */


package de.uniAugsburg.agilPro.model.commands.gefEmfAdapter;


import org.eclipse.emf.common.command.Command;
import org.eclipse.emf.common.command.CommandStack;
import org.eclipse.emf.common.command.CommandStackListener;





/**
 * Wraps a GEF command stack to behave like a EMF command stack.
 * 
 * @version $Id: GefToEmfCommandStackAdapter.java 92 2006-03-15 00:16:21Z bauermar $
 * @author Markus Bauer <markusbauer@users.sourceforge.net>
 */
public class GefToEmfCommandStackAdapter
    implements CommandStack
{
  /**
   * The GEF command stack.
   */
  private org.eclipse.gef.commands.CommandStack gefCommandStack;




  /**
   * @param gefCommandStack The GEF command stack.
   */
  public GefToEmfCommandStackAdapter(
      org.eclipse.gef.commands.CommandStack gefCommandStack)
  {
    assert gefCommandStack != null;
    this.gefCommandStack = gefCommandStack;
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#execute(org.eclipse.emf.common.command.Command)
   */
  public void execute(Command command)
  {
    gefCommandStack.execute(new EmfToGefCommandAdapter(command));
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#canRedo()
   */
  public boolean canRedo()
  {
    return gefCommandStack.canRedo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#redo()
   */
  public void redo()
  {
    gefCommandStack.redo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#getRedoCommand()
   */
  public Command getRedoCommand()
  {
    if (gefCommandStack.getRedoCommand() instanceof EmfToGefCommandAdapter)
    {
      return ((EmfToGefCommandAdapter) gefCommandStack.getRedoCommand())
          .getEmfCommand();
    }

    return null;
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#canUndo()
   */
  public boolean canUndo()
  {
    return gefCommandStack.canUndo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#undo()
   */
  public void undo()
  {
    gefCommandStack.undo();
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#getUndoCommand()
   */
  public Command getUndoCommand()
  {
    if (gefCommandStack.getUndoCommand() instanceof EmfToGefCommandAdapter)
    {
      return ((EmfToGefCommandAdapter) gefCommandStack.getUndoCommand())
          .getEmfCommand();
    }

    return null;
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#getMostRecentCommand()
   */
  public Command getMostRecentCommand()
  {
    Object[] commands = gefCommandStack.getCommands();

    if (commands.length > 0)
    {
      Object latest = commands[commands.length - 1];
      if (latest instanceof EmfToGefCommandAdapter)
      {
        return ((EmfToGefCommandAdapter) latest).getEmfCommand();
      }
    }

    return null;
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#flush()
   */
  public void flush()
  {
    gefCommandStack.flush();
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#addCommandStackListener(org.eclipse.emf.common.command.CommandStackListener)
   */
  public void addCommandStackListener(CommandStackListener listener)
  {
    gefCommandStack
        .addCommandStackListener(new EmfToGefCommandStackListenerAdapter(
                                                                         listener));
  }



  /* (non-Javadoc)
   * @see org.eclipse.emf.common.command.CommandStack#removeCommandStackListener(org.eclipse.emf.common.command.CommandStackListener)
   */
  public void removeCommandStackListener(CommandStackListener listener)
  {
    gefCommandStack
        .removeCommandStackListener(new EmfToGefCommandStackListenerAdapter(
                                                                            listener));
  }
}
