/**
 * File:    AgilProAdapterFactoryEditingDomain.java
 * Created: 30.11.2006
 *
 *
 * Copyright (c) 2006  University of Augsburg <www.informatik.uni-augsburg.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301, USA.
 */


package de.uniAugsburg.agilPro.parts;

import java.util.ArrayList;
import java.util.Collection;

import org.eclipse.emf.common.command.Command;
import org.eclipse.emf.common.command.CommandStack;
import org.eclipse.emf.common.notify.AdapterFactory;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.edit.command.CommandParameter;
import org.eclipse.emf.edit.command.DeleteCommand;
import org.eclipse.emf.edit.domain.AdapterFactoryEditingDomain;

import model.core.ReferenceableElement;
import model.processes.Reference;



/**
 * Adapter Factory that extends the standard {@link AdapterFactoryEditingDomain} 
 * 
 * @version $Id$
 * @author Wolf Fischer
 */
public class AgilProAdapterFactoryEditingDomain extends
		AdapterFactoryEditingDomain {
	
	public AgilProAdapterFactoryEditingDomain(AdapterFactory af, CommandStack cs)
	{
		super(af, cs);
	}
	
	/**
	 * The method checks, if on deletion of a {@link ReferenceableElement} there
	 * are no References point on it! It there are some, the deletion will be aborted!
	 * The cause for this is, that if there are still references and the {@link ReferenceableElement}
	 * will still be deleted, the model file is a mess and not loadable any more!
	 */
	@Override
	public Command createCommand(Class arg0, CommandParameter arg1) {
		
		Command result = null;
		if (arg0 == DeleteCommand.class)
		{
			Object []deleteobjs = arg1.getCollection().toArray();
			Collection col = new ArrayList();
			for (int i = 0; i < deleteobjs.length; i++)
			{
				Object obj = deleteobjs[i];
				
				if (obj instanceof ReferenceableElement)
				{
					if (!existReferences((EObject)obj)) 
					{
//						logger.info("Referencable ELement got no References!");
						col.add(obj);					
					}
//					else
//					{
//						logger.info("Element has references!");
//					}
				}
				else
				{
					col.add(obj);
				}
			}
			result = new DeleteCommand(this, col);
		}
		else
		{
			result = super.createCommand(arg0, arg1);
		}
		return result;
	}
	
	/**
	 * Checks if there are any references on this eobject
	 * @param obj
	 * @return true, if there were references found. Else false
	 */
	private boolean existReferences(EObject obj)
	{
		EObject root = obj.eContainer();
		while (root.eContainer() != null) root = root.eContainer();
		return checkforReferences(root, obj);
	}
	
	/**
	 * Recursively parses the object tree and checks for references
	 * @param container
	 * @param obj
	 * @return false, if there were no references found. Else true
	 */
	private boolean checkforReferences(EObject container, EObject obj)
	{
		EList children = container.eContents();
		boolean result = false;
		for (int i = 0; i < children.size(); i++)
		{
			EObject child = (EObject)children.get(i);
			if (child instanceof Reference)
			{
				Reference ref = (Reference)child;
				if (ref.getReference() == obj) return true;
			}
			else if (child.eContents().size() > 0)
			{
				result = checkforReferences(child, obj) || result;
			}
		}
		return result;
	}
}
